@@ -100,24 +100,31 @@ elseif($_REQUEST['set']=='bind'){
 }
 elseif($_REQUEST['set']=='group'){
 	if($_REQUEST['sim']) {
-		$query=$db->query("select id from scheduler_tem where name='$_REQUEST[group]'");
+		$query=$db->query("select sim_team_id from sim_team where sim_team_name='$_REQUEST[group]'");
 		if($row=$db->fetch_array($query)){
 			$db->query("update sim set sim_team_id='$row[0]' where sim_name='$_REQUEST[sim]'");
-			//$send[]=my_pack2(DEV_BINDING, $_REQUEST['sim'], 0);
+			$send[]=my_pack2(DEV_BINDING, $_REQUEST['sim'], 0);
 			$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$_REQUEST[sim]'");
-			$send[]=my_pack($row, SIM_ADD);
+			if($row=$db->fetch_array($query)){
+				$send[]=my_pack($row, SIM_ADD);
+			}
 			sendto_xchanged($send);
 			echo "OK";
 		}
 		else echo "ERROR group error!";
 	}
 	if($_REQUEST['line']) {
-		$query=$db->query("select id from scheduler_tem where name='$_REQUEST[group]'");
+		$query=$db->query("select sim_team_id from sim_team where sim_team_name='$_REQUEST[group]'");
 		if($row=$db->fetch_array($query)){
 			$db->query("update device_line set goip_team_id='$row[0]' where line_name='$_REQUEST[line]'");
-			//$send[]=my_pack2(DEV_BINDING, $_REQUEST['sim'], 0);
+			$query=$db->query("select sim_name from sim where plan_line_name='$_REQUEST[line]' and line_name='$_REQUEST[line]'");
+			if($row=$db->fetch_array($query)) {
+				$send[]=my_pack2(DEV_BINDING, $row['sim_name'], 0);
+			}
 			$query=$db->query("select device_line.*,password,zone from device_line left join rm_device on device_line.goip_name = rm_device.name where line_name='$_REQUEST[line]'");
-			$send[]=my_pack($row, GOIP_ADD);
+			if($row=$db->fetch_array($query)){
+				$send[]=my_pack($row, GOIP_ADD);
+			}
 			sendto_xchanged($send);
 			echo "OK";
 		}
