@@ -298,7 +298,7 @@ if($action=="main")
 		$start_limit=0;
 		$page=1;
 	}
-	$fenye=showpage2("?order_key=$order_key&order=$order&",$page,$count,$perpage,true,true,"row(s)","myform","boxs");
+	$fenye=showpage2("?goip_name=$_GET[goip_name]&group_id=$_GET[group_id]&order_key=$order_key&order=$order&",$page,$count,$perpage,true,true,"row(s)","myform","boxs");
 	if($order_key) $orderby=" ORDER BY `$order_key` $order_type,device_line.line_name ";
 	else $orderby=" ORDER BY device_line.line_name ";
 	$query=$db->query("SELECT device_line.*,sim_team.*,sim.sim_name,zone,zone_tag,tag FROM device_line left join rm_device on device_line.goip_name = rm_device.name left join sim_team on device_line.goip_team_id=sim_team.sim_team_id left join sim on device_line.line_name=sim.line_name $where $orderby  LIMIT $start_limit,$perpage");
