@@ -137,6 +137,7 @@ if(isset($_GET['action'])) {
                 if($rs[no_ring_disable]) $wa_ck1='checked';
                 if($rs[no_answer_disable]) $wa_ck2='checked';
                 if($rs[short_call_disable]) $wa_ck3='checked';
+		if($rs[count_limit_no_connect]) $ci_no_connect_ck='checked';
 
                 if($rs['remain_time']<0) $rs['remain_time'] = "";
 
@@ -167,7 +168,7 @@ if(isset($_GET['action'])) {
 		if($sim_rs['time_limit']!=$_POST['time_limit']) $t_remain.=",remain_time=$_POST[time_limit]";
 		if($sim_rs['count_limit']!=$_POST['count_limit']) $t_remain.=",count_remain=$_POST[count_limit]";
 		if($sim_rs['no_connected_limit']!=$_POST['no_connected_limit']) $t_remain.=",no_connected_remain=$_POST[no_connected_limit]";
-		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s' $t_remain WHERE sim_name='$sim_name'");
+		$db->query("UPDATE sim SET imei_mode='$imei_mode', sim_team_id='$team_id',dev_disable='$dev_disable',plan_line_name='$_POST[line_name]',imei='$imei',time_limit='$_POST[time_limit]',time_unit='$time_unit',no_ring_limit='$_POST[no_ring_limit]',no_answer_limit='$_POST[no_answer_limit]',short_call_limit='$_POST[short_call_limit]',short_time='$_POST[short_time]',no_ring_disable='$_POST[no_ring_disable]',no_answer_disable='$_POST[no_answer_disable]',short_call_disable='$_POST[short_call_disable]',count_limit='$_POST[count_limit]',no_connected_limit='$_POST[no_connected_limit]',auto_reset_remain='$auto_reset_remain',auto_reset_remain_s='$auto_reset_remain_s',count_limit_no_connect='$_POST[count_limit_no_connect]' $t_remain WHERE sim_name='$sim_name'");
 
 
 		$query=$db->query("select sim.*,password from sim left join sim_bank on sim.bank_name=sim_bank.name where sim_name='$sim_name'");
@@ -245,6 +246,7 @@ if(isset($_GET['action'])) {
 			if($_POST['imei_mode_modify']) $sql.="imei_mode='$imei_mode',";
 			if($_POST['time_limit_modify']) $sql.="time_limit='$_POST[time_limit]',remain_time='$_POST[time_limit]',";
 			if($_POST['count_limit_modify']) $sql.="count_limit='$_POST[count_limit]',count_remain=$_POST[count_limit],";
+			if($_POST['count_limit_no_connect_modify']) $sql.="count_limit_no_connect='$_POST[count_limit_no_connect]',";
 			if($_POST['no_connected_limit_modify']) $sql.="no_connected_limit='$_POST[no_connected_limit]',no_connected_remain=$_POST[no_connected_limit],";
 			if($_POST['time_unit_modify']) $sql.="time_unit='$time_unit',";
 			if($_POST['no_ring_modify']) $sql.="no_ring_limit='$_POST[no_ring_limit]',no_ring_disable='$_POST[no_ring_disable]',";
