@@ -357,6 +357,9 @@
 /*1.6.6 add api of get iccid ,imsi and change group; add sim period buffer*/
 	
 /*1.7 fixed memory of xchanged */
+
+/*1.7 add no connected call in call limit */
+	@$db->updatequery("ALTER TABLE  `sim` ADD  `count_limit_no_connect` BOOL NOT NULL");
 	echo "update done! <a href=''  target=_top>Return</a>";
 
 
